@@ -231,6 +231,8 @@ struct sna {
 #define SNA_FORCE_SHADOW	0x20
 #define SNA_FLUSH_GTT		0x40
 #define SNA_IS_HOSTED		0x80
+#define SNA_PERFORMANCE		0x100
+#define SNA_POWERSAVE		0x200
 #define SNA_REPROBE		0x80000000
 
 	unsigned cpu_features;
@@ -288,7 +290,6 @@ struct sna {
 	EntityInfoPtr pEnt;
 	struct pci_device *PciInfo;
 	const struct intel_device_info *info;
-	xmir_screen *xmir;
 
 	ScreenBlockHandlerProcPtr BlockHandler;
 	ScreenWakeupHandlerProcPtr WakeupHandler;
@@ -323,6 +324,13 @@ struct sna {
 	InputHandlerProc uevent_handler;
 #endif
 
+	struct {
+		int fd;
+		uint8_t offset;
+		uint8_t remain;
+		char event[256];
+	} acpi;
+
 	struct sna_render render;
 
 #if DEBUG_MEMORY
@@ -426,25 +434,15 @@ CARD32 sna_render_format_for_depth(int depth);
 
 void sna_debug_flush(struct sna *sna);
 
-static inline bool
-get_window_deltas(PixmapPtr pixmap, int16_t *x, int16_t *y)
-{
-#ifdef COMPOSITE
-	*x = -pixmap->screen_x;
-	*y = -pixmap->screen_y;
-	return pixmap->screen_x | pixmap->screen_y;
-#else
-	*x = *y = 0;
-	return false;
-#endif
-}
-
 static inline bool
 get_drawable_deltas(DrawablePtr drawable, PixmapPtr pixmap, int16_t *x, int16_t *y)
 {
 #ifdef COMPOSITE
-	if (drawable->type == DRAWABLE_WINDOW)
-		return get_window_deltas(pixmap, x, y);
+	if (drawable->type == DRAWABLE_WINDOW) {
+		*x = -pixmap->screen_x;
+		*y = -pixmap->screen_y;
+		return pixmap->screen_x | pixmap->screen_y;
+	}
 #endif
 	*x = *y = 0;
 	return false;
@@ -939,6 +937,17 @@ box_intersect(BoxPtr a, const BoxRec *b)
 unsigned sna_cpu_detect(void);
 char *sna_cpu_features_to_string(unsigned features, char *line);
 
+/* sna_acpi.c */
+int sna_acpi_open(void);
+void sna_acpi_init(struct sna *sna);
+void _sna_acpi_wakeup(struct sna *sna);
+static inline void sna_acpi_wakeup(struct sna *sna, void *read_mask)
+{
+	if (sna->acpi.fd >= 0 && FD_ISSET(sna->acpi.fd, (fd_set*)read_mask))
+		_sna_acpi_wakeup(sna);
+}
+void sna_acpi_fini(struct sna *sna);
+
 void sna_threads_init(void);
 int sna_use_threads (int width, int height, int threshold);
 void sna_threads_run(void (*func)(void *arg), void *arg);
@@ -957,18 +966,4 @@ void sna_image_composite(pixman_op_t        op,
 			 uint16_t           width,
 			 uint16_t           height);
 
-/* sna_xmir.c */
-
-#if XMIR
-bool sna_xmir_create(struct sna *sna);
-bool sna_xmir_pre_init(struct sna *sna);
-void sna_xmir_init(struct sna *sna, ScreenPtr screen);
-void sna_xmir_post_damage(struct sna *sna);
-#else
-inline static bool sna_xmir_create(struct sna *sna) { return true; }
-inline static bool sna_xmir_pre_init(struct sna *sna) { return true; }
-inline static void sna_xmir_init(struct sna *sna, ScreenPtr screen) { }
-inline static void sna_xmir_post_damage(struct sna *sna) { }
-#endif
-
 #endif /* _SNA_H */
