@@ -421,6 +421,7 @@ static Bool sna_pre_init(ScrnInfoPtr scrn, int flags)
 		scrn->driverPrivate = sna;
 
 		sna->cpu_features = sna_cpu_detect();
+		sna->acpi.fd = sna_acpi_open();
 	}
 	sna = to_sna(scrn);
 	sna->scrn = scrn;
@@ -442,9 +443,6 @@ static Bool sna_pre_init(ScrnInfoPtr scrn, int flags)
 		goto cleanup;
 	}
 
-	if (!sna_xmir_create(sna))
-		goto cleanup;
-
 	/* Sanity check */
 	if (hosted() && (sna->flags & SNA_IS_HOSTED) == 0) {
 		xf86DrvMsg(scrn->scrnIndex, X_ERROR,
@@ -452,14 +450,9 @@ static Bool sna_pre_init(ScrnInfoPtr scrn, int flags)
 		goto cleanup;
 	}
 
-	if (sna->xmir) {
-		/* XXX query depth from xmir */
+	preferred_depth = sna->info->gen < 030 ? 15 : 24;
+	if (!fb_supports_depth(fd, preferred_depth))
 		preferred_depth = 24;
-	} else {
-		preferred_depth = sna->info->gen < 030 ? 15 : 24;
-		if (!fb_supports_depth(fd, preferred_depth))
-			preferred_depth = 24;
-	}
 
 	if (!xf86SetDepthBpp(scrn, preferred_depth, 0, 0,
 			     Support32bppFb |
@@ -496,9 +489,6 @@ static Bool sna_pre_init(ScrnInfoPtr scrn, int flags)
 
 	intel_detect_chipset(scrn, sna->pEnt, sna->PciInfo);
 
-	if (!sna_xmir_pre_init(sna))
-		goto cleanup;
-
 	kgem_init(&sna->kgem, fd, sna->PciInfo, sna->info->gen);
 	if (xf86ReturnOptValBool(sna->Options, OPTION_ACCEL_DISABLE, FALSE) ||
 	    !sna_option_cast_to_bool(sna, OPTION_ACCEL_METHOD, TRUE)) {
@@ -557,6 +547,8 @@ static Bool sna_pre_init(ScrnInfoPtr scrn, int flags)
 	if (sna_option_cast_to_bool(sna, OPTION_DRI, TRUE))
 		sna->dri_available = !!xf86LoadSubModule(scrn, "dri2");
 
+	sna_acpi_init(sna);
+
 	return TRUE;
 
 cleanup:
@@ -582,8 +574,6 @@ sna_block_handler(BLOCKHANDLER_ARGS_DECL)
 
 	if (*tv == NULL || ((*tv)->tv_usec | (*tv)->tv_sec))
 		sna_accel_block_handler(sna, tv);
-
-	sna_xmir_post_damage(sna);
 }
 
 static void
@@ -601,6 +591,8 @@ sna_wakeup_handler(WAKEUPHANDLER_ARGS_DECL)
 	if ((int)result < 0)
 		return;
 
+	sna_acpi_wakeup(sna, read_mask);
+
 	sna->WakeupHandler(WAKEUPHANDLER_ARGS);
 
 	sna_accel_wakeup_handler(sna);
@@ -931,8 +923,6 @@ sna_screen_init(SCREEN_INIT_ARGS_DECL)
 	if (!miDCInitialize(screen, xf86GetPointerScreenFuncs()))
 		return FALSE;
 
-	sna_xmir_init(sna, screen); /* after DirectCursor is initialised */
-
 	if ((sna->flags & SNA_IS_HOSTED) == 0 &&
 	    xf86_cursors_init(screen, SNA_CURSOR_X, SNA_CURSOR_Y,
 			       HARDWARE_CURSOR_TRUECOLOR_AT_8BPP |
@@ -1016,6 +1006,7 @@ static void sna_free_screen(FREE_SCREEN_ARGS_DECL)
 	scrn->driverPrivate = (void *)((uintptr_t)sna->info | 1);
 
 	sna_mode_fini(sna);
+	sna_acpi_fini(sna);
 	free(sna);
 
 	intel_put_device(scrn);
